@@ -1,6 +1,6 @@
 --GregorioTeX Signs Lua support file.
 --
---Copyright (C) 2015 The Gregorio Project (see CONTRIBUTORS.md)
+--Copyright (C) 2015-2017 The Gregorio Project (see CONTRIBUTORS.md)
 --
 --This file is part of Gregorio.
 --
@@ -19,12 +19,13 @@
 
 -- this file contains lua functions to support signs used by GregorioTeX.
 
--- GREGORIO_VERSION 4.1.4
+-- GREGORIO_VERSION 5.0.2
 
 local err = gregoriotex.module.err
 local warn = gregoriotex.module.warn
 local info = gregoriotex.module.info
 local log = gregoriotex.module.log
+local debugmessage = gregoriotex.module.debugmessage
 
 -- Note offset cases:
 -- here are the common values for both hepisema (and consequently also for
@@ -111,8 +112,8 @@ local offset_cases = {
   -- punctum inclinatum as last note
   {
     case = 'FinalInclinatum',
-    v = [[\gre@vepisemaorrareaux{0}{\GreCPPunctumInclinatum}{0}{30\the\gre@factor }{#2}{#3}{#4}]],
-    h = [[\gre@hepisorlineaux{\GreCPPunctumInclinatum}{\gre@char@he@inclinatum{#4}}{2}{#3}]],
+    v = [[\gre@vepisemaorrareaux{0}{\GreCPDescendensPunctumInclinatum}{0}{30\the\gre@factor }{#2}{#3}{#4}]],
+    h = [[\gre@hepisorlineaux{\GreCPDescendensPunctumInclinatum}{\gre@char@he@inclinatum{#4}}{2}{#3}]],
   },
   -- punctum inclinatum deminutus as last note
   {
@@ -135,8 +136,8 @@ local offset_cases = {
   -- oriscus as last note
   {
     case = 'FinalOriscus',
-    v = [[\gre@vepisemaorrareaux{0}{\GreCPOriscus}{0}{0}{#2}{#3}{#4}]],
-    h = [[\gre@hepisorlineaux{\GreCPOriscus}{\gre@char@he@oriscus{#4}}{2}{#3}]],
+    v = [[\gre@vepisemaorrareaux{0}{\GreCPAscendensOriscus}{0}{0}{#2}{#3}{#4}]],
+    h = [[\gre@hepisorlineaux{\GreCPAscendensOriscus}{\gre@char@he@oriscus{#4}}{2}{#3}]],
   },
   -- second-to-last note, with a second ambitus of one, when last note is a
   -- standard punctum (like the second note of ghg)
@@ -155,7 +156,7 @@ local offset_cases = {
   -- oriscus as first note, disconnected from next note
   {
     case = 'InitialOriscus',
-    v = [[\gre@vepisemaorrareaux{0}{\GreCPOriscusReversus}{0}{0}{#2}{#3}{#4}]],
+    v = [[\gre@vepisemaorrareaux{0}{\GreCPDescendensOriscus}{0}{0}{#2}{#3}{#4}]],
     h = [[\gre@hepisorlineaux{0}{\gre@char@he@oriscus{#4}}{0}{#3}]],
   },
   -- quilisma as first note, disconnected from next note
@@ -370,7 +371,7 @@ local offset_cases = {
   -- oriscus as first note, connected to next higher note
   {
     case = 'InitialConnectedOriscus',
-    v = [[\gre@vepisemaorrareaux{0}{\GreCPOriscusLineTR}{0}{0}{#2}{#3}{#4}]],
+    v = [[\gre@vepisemaorrareaux{0}{\GreCPAscendensOriscusLineTR}{0}{0}{#2}{#3}{#4}]],
     h = [[\gre@hepisorlineaux{0}{\gre@char@he@oriscus@line@tr{#4}}{0}{#3}]],
   },
   -- punctum as last note, connected to prior higher note
@@ -407,14 +408,14 @@ local offset_cases = {
   -- least two
   {
     case = 'SalicusOriscusWide',
-    v = [[\gre@vepisemaorrareaux{\GreCPVirgaStrataThreeNothing}{\GreCPSalicusOriscus}{3}{0}{#2}{#3}{#4}]],
-    h = [[\gre@hepisorlineaux{\GreCPVirgaStrataThreeNothing}{\gre@char@he@salicus@oriscus{#4}}{4}{#3}]],
+    v = [[\gre@vepisemaorrareaux{\GreCPPesAscendensOriscusThreeNothing}{\GreCPAscendensOriscusLineBLTR}{3}{0}{#2}{#3}{#4}]],
+    h = [[\gre@hepisorlineaux{\GreCPPesAscendensOriscusThreeNothing}{\gre@char@he@salicus@oriscus{#4}}{4}{#3}]],
   },
   -- "oriscus" as the middle note of a salicus with a second ambitus of one
   {
     case = 'SalicusOriscusOne',
-    v = [[\gre@vepisemaorrareaux{\GreCPVirgaStrataOneNothing}{\GreCPOriscus}{3}{0}{#2}{#3}{#4}]],
-    h = [[\gre@hepisorlineaux{\GreCPVirgaStrataOneNothing}{\gre@char@he@salicus@oriscus{#4}}{4}{#3}]],
+    v = [[\gre@vepisemaorrareaux{\GreCPPesAscendensOriscusOneNothing}{\GreCPAscendensOriscus}{3}{0}{#2}{#3}{#4}]],
+    h = [[\gre@hepisorlineaux{\GreCPPesAscendensOriscusOneNothing}{\gre@char@he@salicus@oriscus{#4}}{4}{#3}]],
   },
   -- punctum fused to the next note
   {
@@ -431,8 +432,8 @@ local offset_cases = {
   -- oriscus fused to the next note
   {
     case = 'LeadingOriscus',
-    v = [[\gre@vepisemaorrareaux{0}{\GreCPOriscus}{0}{0}{#2}{#3}{#4}]],
-    h = [[\gre@hepisorlineaux{\GreCPOriscusTwoUp}{\gre@char@he@oriscus{#4}}{2}{#3}]],
+    v = [[\gre@vepisemaorrareaux{0}{\GreCPAscendensOriscus}{0}{0}{#2}{#3}{#4}]],
+    h = [[\gre@hepisorlineaux{\GreCPAscendensOriscusTwoUp}{\gre@char@he@oriscus{#4}}{2}{#3}]],
   },
   -- flat
   {
@@ -457,7 +458,7 @@ local offset_cases = {
 local function emit_offset_macros()
   local i, item
   for i, item in ipairs(offset_cases) do
-    log([[\def\GreOCase%s{%d}]], item.case, i)
+    debugmessage('offsetcase', [[\def\GreOCase%s{%d}]], item.case, i)
     tex.sprint(string.format([[\def\GreOCase%s{%d}]], item.case, i))
   end
   tex.sprint([[\def\gre@v@case#1#2#3#4{]])
